is_most_derived_contract

Function is_most_derived_contract 

fn is_most_derived_contract(hir: &Hir<'_>, contract_id: ContractId) -> bool
Slither analyzes the effective entry points of leaf contracts so inherited declarations are interpreted in the context in which they are ultimately deployed.