fn is_most_derived_contract(hir: &Hir<'_>, contract_id: ContractId) -> boolExpand description
Slither analyzes the effective entry points of leaf contracts so inherited declarations are interpreted in the context in which they are ultimately deployed.